module adcIf(
    input CLK32M,
    output adcClk,
    output adcDin,
    input  adc1Dout,
    input  adc2Dout,
    output reg adc1Cs, 
    output reg adc2Cs, 
    output out_valid,
    output [9:0] out_data,
    output [3:0] out_chan);

   // initial values force a reset via falling Cs edge for the first ADC at startup
   initial begin
      adc1Cs = 1;
      adc2Cs = 1;
   end

   // addressing shift register
   // MSB comes out first after 2 cycles delay
   reg 	     [4:0] addrOut = 0;
   assign adcDin = addrOut[4];
   
   // channel that is being read in current frame
   reg [8:0] 	 counter = 510; // init val: load address
   
   // strobe indicating valid data
   assign out_valid = (counter[4:0] == 5'd25);
   
   // channel that will be read in next frame
   // note: addressing wraps around inside each individual DAC
   wire [2:0] 	 addrNextFrame = counter[7:5] + 1;
   assign out_chan = out_valid ? counter[8:5] : 4'hx;
   
   // alternate capture between DACs
   wire 	 chipSel = counter[8];
   
   // output data goes here
   reg [9:0] 	 out_dataReg;
   assign out_data = out_valid ? out_dataReg : 10'hx;

   // clock at 16 MHz which is max. rated speed
   assign adcClk = !counter[0];
         
   always @(posedge CLK32M) begin
      counter <= counter+1;
      adc1Cs <= chipSel;
      adc2Cs <= !chipSel;

      // falling clock edge
      if (!counter[0]) begin
	 if (counter[4:1] == 0) begin
	    // 16 cycles complete: new frame
	    addrOut <= {2'd0, addrNextFrame};
	 end else begin
	   // update address
	   addrOut <= addrOut << 1;
	 end	 	 
      end else begin
	 // rising edge
	 // update data from the DAC that is currently active
	 out_dataReg = {out_dataReg[8:0], chipSel ? adc2Dout : adc1Dout};
      end
   end
endmodule
