module impl(input CLK32M,
    output reg LED,
    output     TX_USB,
    output     ADC1CS,
    output     ADC1CLK,
    output     ADC1DIN,
    input      ADC1DOUT,
    output     ADC2CS,
    output     ADC2CLK,
    output     ADC2DIN,
    input      ADC2DOUT);

   wire        valid;
   wire [7:0] 	  data;
   wire [3:0] 	  chan;

   wire 	  w_adcDin;
   assign ADC1DIN=w_adcDin;
   assign ADC2DIN=w_adcDin;

   wire 	  w_adcClk;
   assign ADC1CLK=w_adcClk;
   assign ADC2CLK=w_adcClk;
   
   // ADC interface
   adcIf instAdcIf
     (.CLK32M(CLK32M),
      .adcClk(w_adcClk),
      .adcDin(w_adcDin),
      .adc1Dout(ADC1DOUT),
      .adc2Dout(ADC2DOUT),
      .adc1Cs(ADC1CS),
      .adc2Cs(ADC2CS),
      .out_valid(valid),
      .out_data(data),
      .out_chan(chan));
   
   // counter to skip samples
   reg [11:0] 	  count = 0;

   reg [7:0] 	  PWM = 0;
   // fifo prints hex to USB
   fifo_ctrl instFifoCtrl(.clk(CLK32M), .chan(chan), .val(data), .trig(valid && (count==0)), .tx(TX_USB));
   
   always @(posedge CLK32M) begin 
      if (valid && chan == 0) 
	 count <= count + 1;
            
      if (valid && (chan == 0)) begin
	 PWM <= data;
      end
      LED <= (count[7:0] < PWM);
   end
endmodule

   